=========================
kpireport-googleanalytics
=========================

.. image:: https://img.shields.io/pypi/v/kpireport-googleanalytics
   :target: https://pypi.org/project/kpireport-googleanalytics

.. code-block::

   pip install kpireport-googleanalytics
